@@ -247,10 +247,10 @@ class DeviceDcElwa(ModbusRtuDevice):
         modbusErrorRate = self.getcommunicationerrorsrate()
         
         if modbusError == False:
-            if modbusErrorRate == 1 :
+            if modbusErrorRate != None and modbusErrorRate >= 0.70:
                 logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus communication to device not working.")
                 modbusError = True
-            else:
+            else:                    
                 modbusError = False
 
         registerisvalid = self.__checkRegiterTimeStamp__()
@@ -260,7 +260,7 @@ class DeviceDcElwa(ModbusRtuDevice):
         else:
             registerError = False
 
-        if registerError == False and modbusError != True and modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 1:
+        if registerError == False and modbusError == False and modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 0.7:
             logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
             modbusWarning = True
         else:
@@ -287,7 +287,8 @@ class DeviceDcElwa(ModbusRtuDevice):
 
         self.__seterrorcode__(irerror=irError, modbuserror=modbusError, registererror=registerError, temp1error=temp1error, temp2error=temp2error, opmodeerror=opmodeError, modbuswarning=modbusWarning)
 
-        self.__sethealthstate__(healthState)
+        if modbusErrorRate != None or healthState == 2:
+            self.__sethealthstate__(healthState)
 
     def __seterrorcode__(self, modbuserror=0, irerror=0, registererror=0, temp1error=0, temp2error=0, opmodeerror=0, modbuswarning=0):
         if modbuswarning: 
@@ -494,8 +495,8 @@ if __name__ == "__main__":
     try:
         while True:
             print(color('[DeviceDcElwa] test active. Press CTRL+C to stop', fore='blue', style='bright'))
-            device.showinfo()
-            device.showcommunicationerrors()
+            # device.showinfo()
+            # device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
             time.sleep(10)
     except KeyboardInterrupt as e:
